summaryrefslogtreecommitdiff
path: root/src/model/library.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/model/library.rs')
-rw-r--r--src/model/library.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/model/library.rs b/src/model/library.rs
index 63bd5839..02eb9179 100644
--- a/src/model/library.rs
+++ b/src/model/library.rs
@@ -74,8 +74,8 @@ pub struct LangItems {
fn(base: Content, sub: Option<Content>, sup: Option<Content>) -> Content,
/// A fraction in a formula: `x/2`.
pub math_frac: fn(num: Content, denom: Content) -> Content,
- /// An alignment indicator in a formula: `&`, `&&`.
- pub math_align: fn(count: usize) -> Content,
+ /// An alignment point in a formula: `&`, `&&`.
+ pub math_align_point: fn(count: usize) -> Content,
}
impl Debug for LangItems {
@@ -107,7 +107,7 @@ impl Hash for LangItems {
self.math_atom.hash(state);
self.math_script.hash(state);
self.math_frac.hash(state);
- self.math_align.hash(state);
+ self.math_align_point.hash(state);
}
}